@@ -38,7 +38,6 @@ CONFIG_TIME_FRAME = "time_frame"
 USER_FOLDER = "user"
 CONFIG_FOLDER = "config"
 CONFIG_FILE = "config.json"
-TEMP_RESTORE_CONFIG_FILE = "temp_config.json"
 SAFE_DUMP_SUFFIX = ".back"
 DEFAULT_CONFIG_FILE = "default_config.json"
 DEFAULT_CONFIG_FILE_PATH = f"{CONFIG_FOLDER}/{DEFAULT_CONFIG_FILE}"
@@ -61,11 +60,14 @@ CONFIG_BACKTESTING_PROFILE = "backtesting_profile"
 DEFAULT_PROFILE = "default"
 DEFAULT_PROFILE_FILE = f"{CONFIG_PROFILE}.json"
 CONFIG_NAME = "name"
+CONFIG_SLUG = "slug"
 CONFIG_DESCRIPTION = "description"
 CONFIG_AVATAR = "avatar"
 CONFIG_ORIGIN_URL = "origin_url"
+CONFIG_AUTO_UPDATE = "auto_update"
 CONFIG_READ_ONLY = "read_only"
 CONFIG_IMPORTED = "imported"
+CONFIG_EXTRA_BACKTESTING_TIME_FRAMES = "extra_backtesting_time_frames"
 CONFIG_COMPLEXITY = "complexity"
 CONFIG_RISK = "risk"
 CONFIG_TYPE = "type"
@@ -75,6 +77,7 @@ PROFILE_FILE_SCHEMA = f"{CONFIG_FOLDER}/profile_{SCHEMA}.json"
 PROFILE_EXPORT_FORMAT = "zip"
 IMPORTED_PROFILE_PREFIX = "imported"
 USE_CURRENT_PROFILE = "use_current_profile"
+PROFILE_REFRESH_HOURS_INTERVAL = int(os.getenv("PROFILE_REFRESH_HOURS_INTERVAL", "24"))
 
 # Config currencies
 CONFIG_CRYPTO_CURRENCIES = "crypto-currencies"
@@ -82,14 +85,18 @@ CONFIG_CRYPTO_CURRENCY = "crypto-currency"
 CONFIG_CRYPTO_PAIRS = "pairs"
 CONFIG_CRYPTO_QUOTE = "quote"
 CONFIG_CRYPTO_ADD = "add"
+TRADING_SYMBOL_REGEX = "([a-zA-Z]|\\d){1,}\\/([a-zA-Z]|\\d){1,}"
 
 # Exchange
 CONFIG_EXCHANGES = "exchanges"
 CONFIG_EXCHANGE_KEY = "api-key"
 CONFIG_EXCHANGE_SECRET = "api-secret"
 CONFIG_EXCHANGE_PASSWORD = "api-password"
+CONFIG_EXCHANGE_UID = "api-uid"
+CONFIG_EXCHANGE_ACCESS_TOKEN = "access_token"
 CONFIG_EXCHANGE_TYPE = "exchange-type"
 CONFIG_CONTRACT_TYPE = "contract-type"
+CONFIG_REQUIRED_EXTRA_TIMEFRAMES = "required_extra_timeframes"
 CONFIG_EXCHANGE_SANDBOXED = "sandboxed"
 CONFIG_EXCHANGE_FUTURE = "future"
 CONFIG_EXCHANGE_MARGIN = "margin"
@@ -148,6 +155,7 @@ CONFIG_TENTACLES_FILE = "tentacles_config.json"
 EVALUATOR_PRIORITY = "priority"
 DEFAULT_EVALUATOR_PRIORITY = 0
 CONFIG_TENTACLES_REQUIRED_CANDLES_COUNT = "required_candles_count"
+CONFIG_HISTORICAL_CONFIGURATION = "_historical_configuration"
 NESTED_TENTACLE_CONFIG = "nested_tentacle_configuration"
 CONFIG_ACTIVATION_TOPICS = "activation method"
 CONFIG_TRIGGER_TIMEFRAMES = "Trigger_timeframes"
@@ -158,11 +166,16 @@ ALLOW_DEFAULT_CONFIG = "allow_default_config"
 # terms of service
 CONFIG_ACCEPTED_TERMS = "accepted_terms"
 
+# distribution
+CONFIG_DISTRIBUTION = "distribution"
+
 # metrics
 CONFIG_METRICS = "metrics"
 CONFIG_METRICS_BOT_ID = "metrics-bot-id"
 TIMER_BEFORE_METRICS_REGISTRATION_SECONDS = 600
-TIMER_BETWEEN_METRICS_UPTIME_UPDATE = 3600 * 4
+TIMER_BETWEEN_METRICS_UPTIME_UPDATE = float(
+    os.getenv("TIMER_BETWEEN_METRICS_UPTIME_UPDATE", str(3600 * 4))
+)
 METRICS_URL = os.getenv("METRICS_OCTOBOT_ONLINE_URL", "https://metrics.octobot.online/")
 METRICS_ROUTE_GEN_BOT_ID = "gen-bot-id"
 METRICS_ROUTE = "metrics"
@@ -176,12 +189,13 @@ DEFAULT_API_KEY = "your-api-key-here"
 DEFAULT_API_SECRET = "your-api-secret-here"
 DEFAULT_API_PASSWORD = "your-api-password-here"
 DEFAULT_EXCHANGE_TYPE = CONFIG_EXCHANGE_SPOT
+NO_KEY_VALUE = "NO KEY"
 DEFAULT_CONFIG_VALUES = {
     DEFAULT_API_KEY,
     DEFAULT_API_SECRET,
     DEFAULT_API_PASSWORD,
     "NOKEY",
-    "NO KEY",
+    NO_KEY_VALUE,
     "Empty",
 }
 
@@ -224,6 +238,8 @@ USD_LIKE_COINS = [
     "USDT",
     "USDC",
     "TUSD",
+    "USDE",
+    "USDS",
     "BUSD",
     "DAI",
     "USD",
@@ -240,3 +256,22 @@ USD_LIKE_COINS = [
     "BOB",
     "MIMATIC",
 ]
+
+# from coinbase and binance fiat pairs
+FIAT_NON_USD_LIKE_COINS = [
+    "EUR",
+    "GBP",
+    "TRY",
+    "BRL",
+    "ARS",
+]
+
+USD_LIKE_AND_FIAT_COINS = USD_LIKE_COINS + FIAT_NON_USD_LIKE_COINS
+
+ENABLE_CERTIFI_SSL_CERTIFICATES = bool(
+    os.getenv("ENABLE_CERTIFI_SSL_CERTIFICATES", "true").lower() == "true"
+)
+KNOWN_POTENTIALLY_SSL_FAILED_REQUIRED_URL = (
+    "https://tentacles.octobot.online/officials/packages/full/base/1.0.9/metadata.yaml"
+)
+IS_DEV_MODE_ENABLED = bool(os.getenv(CONFIG_DEBUG_OPTION, "False").lower() == "true")
