@@ -21,6 +21,12 @@ class ConfigError(Exception):
     """
 
 
+class RemoteConfigError(ConfigError):
+    """
+    Fetched config related Exception
+    """
+
+
 class NoProfileError(Exception):
     """
     Profile related Exception: raised when the current profile can't be found and default profile can't be loaded
