@@ -16,9 +16,11 @@
 #  License along with this library.
 import contextlib
 import logging
+import typing
 
 import octobot_commons.constants as constants
 import octobot_commons.timestamp_util as timestamp_util
+import octobot_commons.html_util as html_util
 
 LOG_DATABASE = "log_db"
 LOG_NEW_ERRORS_COUNT = "log_new_errors_count"
@@ -46,6 +48,7 @@ def _default_callback(*_, **__):
 
 
 _ERROR_CALLBACK = _default_callback
+_LOG_CALLBACK: typing.Union[None, typing.Callable[[str], str]] = None
 
 
 def set_global_logger_level(level, handler_levels=None) -> None:
@@ -171,47 +174,51 @@ class BotLogger:
         self.logger_name = logger_name
         self.logger = logging.getLogger(logger_name)
 
-    def debug(self, message, *args, **kwargs) -> None:
+    def debug(self, message: str, *args, **kwargs) -> None:
         """
         Called for a debug log
         :param message: the log message
         """
+        message = self._process_log_callback(message)
         self.logger.debug(message, *args, **kwargs)
         self._publish_log_if_necessary(message, logging.DEBUG)
 
-    def info(self, message, *args, **kwargs) -> None:
+    def info(self, message: str, *args, **kwargs) -> None:
         """
         Called for an info log
         :param message: the log message
         """
+        message = self._process_log_callback(message)
         self.logger.info(message, *args, **kwargs)
         self._publish_log_if_necessary(message, logging.INFO)
 
-    def warning(self, message, *args, **kwargs) -> None:
+    def warning(self, message: str, *args, **kwargs) -> None:
         """
         Called for a warning log
         :param message: the log message
         """
+        message = self._process_log_callback(message)
         self.logger.warning(message, *args, **kwargs)
         self._publish_log_if_necessary(message, logging.WARNING)
 
-    def error(self, message, *args, skip_post_callback=False, **kwargs) -> None:
+    def error(self, message: str, *args, skip_post_callback=False, **kwargs) -> None:
         """
         Called for an error log
         :param message: the log message
         :param skip_post_callback: when True, the error callback wont be called
         """
+        message = self._process_log_callback(message)
         self.logger.error(message, *args, **kwargs)
         self._publish_log_if_necessary(message, logging.ERROR)
         self._post_callback_if_necessary(None, message, skip_post_callback)
 
     def exception(
         self,
-        exception,
-        publish_error_if_necessary=True,
-        error_message=None,
-        include_exception_name=True,
-        skip_post_callback=False,
+        exception: Exception,
+        publish_error_if_necessary: bool = True,
+        error_message: str = None,
+        include_exception_name: bool = True,
+        skip_post_callback: bool = False,
         **kwargs,
     ) -> None:
         """
@@ -220,13 +227,20 @@ class BotLogger:
         :param publish_error_if_necessary: if the error should be published
         :param error_message: the log message
         :param include_exception_name: when True adds the __class__.__name__ of the exception at the end of the message
-        :param skip_post_callback: when True, the error callback wont be called
+        :param skip_post_callback: when True, the error callback won't be called
         """
         extra = kwargs.get("extra", {})
+        origin_error_message = error_message
+        error_message = (
+            self._process_log_callback(error_message)
+            if error_message
+            else error_message
+        )
         extra[constants.EXCEPTION_DESC] = error_message
+        html_util.summarize_exception_html_cause_if_relevant(exception)
         self.logger.exception(exception, extra=extra, **kwargs)
         if publish_error_if_necessary:
-            message = error_message
+            message = origin_error_message
             if message is None:
                 message = (
                     str(exception) if str(exception) else exception.__class__.__name__
@@ -240,19 +254,21 @@ class BotLogger:
             )
         self._post_callback_if_necessary(exception, error_message, skip_post_callback)
 
-    def critical(self, message, *args, **kwargs) -> None:
+    def critical(self, message: str, *args, **kwargs) -> None:
         """
         Called for a critical log
         :param message: the log message
         """
+        message = self._process_log_callback(message)
         self.logger.critical(message, *args, **kwargs)
         self._publish_log_if_necessary(message, logging.CRITICAL)
 
-    def fatal(self, message, *args, **kwargs) -> None:
+    def fatal(self, message: str, *args, **kwargs) -> None:
         """
         Called for a fatal log
         :param message: the log message
         """
+        message = self._process_log_callback(message)
         self.logger.fatal(message, *args, **kwargs)
         self._publish_log_if_necessary(message, logging.FATAL)
 
@@ -263,6 +279,11 @@ class BotLogger:
         """
         self.logger.disabled = disabled
 
+    def _process_log_callback(self, message: str) -> str:
+        if _LOG_CALLBACK is None:
+            return message
+        return _LOG_CALLBACK(message)
+
     def _publish_log_if_necessary(self, message, level) -> None:
         """
         Publish the log message if necessary
@@ -307,6 +328,15 @@ class BotLogger:
             _ERROR_CALLBACK(exception, error_message)
 
 
+def register_log_callback(callback: typing.Union[None, typing.Callable[[str], str]]):
+    """
+    :param callback: the callback to be called upon any log of any level
+    Register callback as the _LOG_CALLBACK
+    """
+    global _LOG_CALLBACK
+    _LOG_CALLBACK = callback
+
+
 def get_backtesting_errors_count() -> int:
     """
     Get backtesting errors count
