@@ -63,15 +63,18 @@ class Profile:
         self.path: str = profile_path
         self.schema_path: str = schema_path or constants.PROFILE_FILE_SCHEMA
         self.name: str = None
+        self.slug: str = None
         self.description: str = None
         self.avatar: str = None
         self.avatar_path: str = None
         self.origin_url: str = None
+        self.auto_update: bool = False
         self.read_only: bool = False
         self.imported: bool = False
         self.complexity: enums.ProfileComplexity = enums.ProfileComplexity.MEDIUM
         self.risk: enums.ProfileRisk = enums.ProfileRisk.MODERATE
         self.profile_type: enums.ProfileType = enums.ProfileType.LIVE
+        self.extra_backtesting_time_frames = []
 
         self.config: dict = {}
 
@@ -90,9 +93,11 @@ class Profile:
         profile_config = profile_dict.get(constants.CONFIG_PROFILE, {})
         self.profile_id = profile_config.get(constants.CONFIG_ID, str(uuid.uuid4()))
         self.name = profile_config.get(constants.CONFIG_NAME, "")
+        self.slug = profile_config.get(constants.CONFIG_SLUG, "")
         self.description = profile_config.get(constants.CONFIG_DESCRIPTION, "")
         self.avatar = profile_config.get(constants.CONFIG_AVATAR, "")
         self.origin_url = profile_config.get(constants.CONFIG_ORIGIN_URL, None)
+        self.auto_update = profile_config.get(constants.CONFIG_AUTO_UPDATE, False)
         self.read_only = profile_config.get(constants.CONFIG_READ_ONLY, False)
         self.imported = profile_config.get(constants.CONFIG_IMPORTED, False)
         self.complexity = enums.ProfileComplexity(
@@ -106,6 +111,9 @@ class Profile:
         self.profile_type = enums.ProfileType(
             profile_config.get(constants.CONFIG_TYPE, enums.ProfileType.LIVE.value)
         )
+        self.extra_backtesting_time_frames = profile_config.get(
+            constants.CONFIG_EXTRA_BACKTESTING_TIME_FRAMES, []
+        )
         self.config = profile_dict[constants.PROFILE_CONFIG]
         if self.avatar and self.path:
             avatar_path = os.path.join(self.path, self.avatar)
@@ -157,7 +165,12 @@ class Profile:
         Validate this profile configuration against self.schema_path
         :return:
         """
-        json_util.validate(self.as_dict(), self.schema_path)
+        try:
+            json_util.validate(self.as_dict(), self.schema_path)
+        except FileNotFoundError as err:
+            commons_logging.get_logger("ProfileSaver").warning(
+                f"Impossible to validate profile: {err} ({err.__class__.__name__})"
+            )
 
     def validate_and_save_config(self) -> None:
         """
@@ -212,6 +225,7 @@ class Profile:
         clone.read_only = False
         clone.imported = False
         clone.origin_url = None
+        clone.auto_update = False
         try:
             clone.path = os.path.join(
                 os.path.split(self.path)[0], f"{clone.name}_{clone.profile_id}"
@@ -238,9 +252,11 @@ class Profile:
             constants.CONFIG_PROFILE: {
                 constants.CONFIG_ID: self.profile_id,
                 constants.CONFIG_NAME: self.name,
+                constants.CONFIG_SLUG: self.slug,
                 constants.CONFIG_DESCRIPTION: self.description,
                 constants.CONFIG_AVATAR: self.avatar,
                 constants.CONFIG_ORIGIN_URL: self.origin_url,
+                constants.CONFIG_AUTO_UPDATE: self.auto_update,
                 constants.CONFIG_READ_ONLY: self.read_only,
                 constants.CONFIG_IMPORTED: self.imported,
                 constants.CONFIG_COMPLEXITY: self.complexity.value
@@ -250,6 +266,7 @@ class Profile:
                 constants.CONFIG_TYPE: self.profile_type.value
                 if self.profile_type
                 else None,
+                constants.CONFIG_EXTRA_BACKTESTING_TIME_FRAMES: self.extra_backtesting_time_frames,
             },
             constants.PROFILE_CONFIG: self.config,
         }
