@@ -1,4 +1,4 @@
-# pylint: disable=C0103,R0902
+# pylint: disable=C0103,R0902,C0301
 #  Drakkar-Software OctoBot-Commons
 #  Copyright (c) Drakkar-Software, All rights reserved.
 #
@@ -29,18 +29,47 @@ class ProfileDetailsData(octobot_commons.dataclasses.FlexibleDataclass):
     id: typing.Union[str, None] = None
     bot_id: typing.Union[str, None] = None
     version: typing.Union[str, None] = None
+    user_id: typing.Union[str, None] = None
+    nested_strategy_config_id: typing.Union[str, None] = None
 
 
 @dataclasses.dataclass
 class CryptoCurrencyData(octobot_commons.dataclasses.FlexibleDataclass):
     trading_pairs: list[str]
     name: typing.Union[str, None] = None
+    enabled: bool = True
 
 
 @dataclasses.dataclass
 class ExchangeData(octobot_commons.dataclasses.FlexibleDataclass):
-    exchange_credential_id: typing.Union[str, None] = None
+    exchange_credential_id: typing.Union[
+        str, None
+    ] = None  # deprecated, use exchange_account_id instead, exchange_credential_id is updated in exchange_data.auth_details
     internal_name: typing.Union[str, None] = None
+    exchange_type: str = constants.DEFAULT_EXCHANGE_TYPE
+    exchange_id: typing.Union[str, None] = None
+    exchange_account_id: typing.Union[str, None] = None
+    sandboxed: bool = False
+
+
+@dataclasses.dataclass
+class FutureSymbolData(octobot_commons.dataclasses.FlexibleDataclass):
+    symbol: str
+    leverage: typing.Union[float, None] = None
+
+
+@dataclasses.dataclass
+class FutureExchangeData(octobot_commons.dataclasses.FlexibleDataclass):
+    default_leverage: typing.Union[float, None] = None
+    symbol_data: list[FutureSymbolData] = dataclasses.field(default_factory=list)
+
+    # pylint: disable=E1134
+    def __post_init__(self):
+        if self.symbol_data and isinstance(self.symbol_data[0], dict):
+            self.symbol_data = [
+                FutureSymbolData.from_dict(symbol_datum)
+                for symbol_datum in self.symbol_data
+            ]
 
 
 @dataclasses.dataclass
@@ -78,6 +107,8 @@ class TradingData(octobot_commons.dataclasses.FlexibleDataclass):
     reference_market: str
     minimal_funds: list[MinimalFund] = dataclasses.field(default_factory=list)
     risk: float = 1.0
+    sub_portfolio: dict[str, float] = dataclasses.field(default_factory=dict)
+    sellable_assets: typing.Optional[list[str]] = None
 
     # pylint: disable=E1134
     def __post_init__(self):
@@ -113,7 +144,10 @@ class ProfileData(octobot_commons.dataclasses.MinimizableDataclass):
     crypto_currencies: list[CryptoCurrencyData]
     trading: TradingData
     exchanges: list[ExchangeData] = dataclasses.field(default_factory=list)
-    trader: TraderData = TraderData()
+    future_exchange_data: FutureExchangeData = dataclasses.field(
+        default_factory=FutureExchangeData
+    )
+    trader: TraderData = dataclasses.field(default_factory=TraderData)
     trader_simulator: TraderSimulatorData = dataclasses.field(
         default_factory=TraderSimulatorData
     )
@@ -160,11 +194,11 @@ class ProfileData(octobot_commons.dataclasses.MinimizableDataclass):
                     {
                         "trading_pairs": details.get(constants.CONFIG_CRYPTO_PAIRS, []),
                         "name": currency,
+                        "enabled": details.get(constants.CONFIG_ENABLED_OPTION, True),
                     }
                     for currency, details in content[
                         constants.CONFIG_CRYPTO_CURRENCIES
                     ].items()
-                    if details.get(constants.CONFIG_ENABLED_OPTION, True)
                 ],
                 "trader": {
                     "enabled": content[constants.CONFIG_TRADER][
@@ -220,14 +254,14 @@ class ProfileData(octobot_commons.dataclasses.MinimizableDataclass):
                 constants.CONFIG_CRYPTO_CURRENCIES: {
                     crypto_currency.name: {
                         constants.CONFIG_CRYPTO_PAIRS: crypto_currency.trading_pairs,
-                        constants.CONFIG_ENABLED_OPTION: True,
+                        constants.CONFIG_ENABLED_OPTION: crypto_currency.enabled,
                     }
                     for crypto_currency in self.crypto_currencies
                 },
                 constants.CONFIG_EXCHANGES: {
                     exchange_details.internal_name: {
                         constants.CONFIG_ENABLED_OPTION: True,
-                        constants.CONFIG_EXCHANGE_TYPE: constants.DEFAULT_EXCHANGE_TYPE,
+                        constants.CONFIG_EXCHANGE_TYPE: exchange_details.exchange_type,
                     }
                     for exchange_details in self.exchanges
                 },
@@ -238,9 +272,11 @@ class ProfileData(octobot_commons.dataclasses.MinimizableDataclass):
                 constants.CONFIG_SIMULATOR: {
                     constants.CONFIG_ENABLED_OPTION: self.trader_simulator.enabled,
                     constants.CONFIG_STARTING_PORTFOLIO: self.trader_simulator.starting_portfolio
-                    or self.backtesting_context.starting_portfolio
-                    if self.backtesting_context
-                    else {},
+                    or (
+                        self.backtesting_context.starting_portfolio
+                        if self.backtesting_context
+                        else {}
+                    ),
                     constants.CONFIG_SIMULATOR_FEES: {
                         constants.CONFIG_SIMULATOR_FEES_MAKER: self.trader_simulator.maker_fees,
                         constants.CONFIG_SIMULATOR_FEES_TAKER: self.trader_simulator.taker_fees,
