@@ -14,18 +14,33 @@
 #
 #  You should have received a copy of the GNU Lesser General Public
 #  License along with this library.
+import typing
 import octobot_commons.enums
 
+import octobot_commons.signals.signal_dependencies as signal_dependencies
+
 
 class Signal:
-    def __init__(self, topic: str, content: dict, **_):
+    def __init__(
+        self,
+        topic: str,
+        content: dict,
+        dependencies: typing.Optional[signal_dependencies.SignalDependencies] = None,
+        **_,
+    ):
         self.topic: str = topic
         self.content: dict = content
+        self.dependencies: typing.Optional[
+            signal_dependencies.SignalDependencies
+        ] = dependencies
 
     def to_dict(self) -> dict:
         return {
             octobot_commons.enums.SignalsAttrs.TOPIC.value: self.topic,
             octobot_commons.enums.SignalsAttrs.CONTENT.value: self.content,
+            octobot_commons.enums.SignalsAttrs.DEPENDENCIES.value: self.dependencies.to_dict()
+            if self.dependencies
+            else None,
         }
 
     def __str__(self):
