@@ -21,6 +21,8 @@ from octobot_commons.symbols.symbol_util import (
     merge_symbol,
     merge_currencies,
     convert_symbol,
+    is_usd_like_coin,
+    get_most_common_usd_like_symbol,
 )
 
 from octobot_commons.symbols import symbol
@@ -35,5 +37,7 @@ __all__ = [
     "merge_symbol",
     "merge_currencies",
     "convert_symbol",
+    "is_usd_like_coin",
+    "get_most_common_usd_like_symbol",
     "Symbol",
 ]
