@@ -32,19 +32,43 @@ def profile_data_dict():
             'name': 'profile_name 42',
             'id': 'default',
             'version': "42.42.1b",
-            'bot_id': "1234-1224-0000"
+            'bot_id': "1234-1224-0000",
+            'user_id': "plop-id",
+            'nested_strategy_config_id': "123-1221"
         },
         'crypto_currencies': [
             {
                 'trading_pairs': ['BTC/USDT'],
-                'name': 'Bitcoin'
+                'name': 'Bitcoin',
+                'enabled': True
+            },
+            {
+                'trading_pairs': ['ETH/USDT'],
+                'name': 'ETH',
+                'enabled': False
             }
         ], 'exchanges': [
             {
                 'exchange_credential_id': '123-plop',
-                'internal_name': 'cryptocom'
+                'exchange_id': '123-exchange',
+                'exchange_account_id': '123-exchange_account_id',
+                'exchange_type': 'spot',
+                'internal_name': 'cryptocom',
+                'sandboxed': True,
             }
-        ], 'trader': {
+        ], 'future_exchange_data': {
+            'default_leverage': 10,
+            'symbol_data': [
+                {
+                    'symbol': 'BTC/USDT',
+                    'leverage': None,
+                },
+                {
+                    'symbol': 'ETH/USDT',
+                    'leverage': 5,
+                }
+            ]
+        }, 'trader': {
             'enabled': True
         }, 'trader_simulator': {
             'enabled': False,
@@ -68,7 +92,12 @@ def profile_data_dict():
                     "total": 0.2222,
                 }
             ],
-            'risk': 0.5
+            'sub_portfolio': {
+                "BTC": 0.1,
+                "USDT": 1000
+            },
+            'risk': 0.5,
+            'sellable_assets': ["BTC", "ETH"]
         }, 'tentacles': [
             {
                 'name': 'plopEvaluator',
@@ -100,6 +129,7 @@ def profile_data_dict():
         }
     }
 
+
 @pytest.fixture
 def min_profile_data_dict():
     return {
@@ -109,6 +139,10 @@ def min_profile_data_dict():
         'crypto_currencies': [
             {
                 'trading_pairs': ['BTC/USDT'],
+            },
+            {
+                'trading_pairs': ['ETH/USDT'],
+                'enabled': False
             }
         ], 'trading': {
             'reference_market': 'BTC',
@@ -183,8 +217,16 @@ def test_from_dict(profile_data_dict):
     # check one element per attribute to be sure it's all parsed
     assert profile_data.profile_details.name == "profile_name 42"
     assert profile_data.crypto_currencies[0].trading_pairs == ['BTC/USDT']
+    assert profile_data.future_exchange_data.default_leverage == 10
+    assert profile_data.future_exchange_data.symbol_data[0].symbol == "BTC/USDT"
+    assert profile_data.future_exchange_data.symbol_data[0].leverage == None
+    assert profile_data.future_exchange_data.symbol_data[1].symbol == "ETH/USDT"
+    assert profile_data.future_exchange_data.symbol_data[1].leverage == 5
     assert profile_data.exchanges[0].exchange_credential_id == "123-plop"
+    assert profile_data.exchanges[0].exchange_account_id == "123-exchange_account_id"
     assert profile_data.exchanges[0].internal_name == "cryptocom"
+    assert profile_data.exchanges[0].sandboxed is True
+    assert profile_data.exchanges[0].exchange_type == "spot"
     assert profile_data.trader.enabled is True
     assert profile_data.trader_simulator.enabled is False
     assert profile_data.trader_simulator.starting_portfolio == {'BTC': 10, 'USDT': 1000}
@@ -204,6 +246,12 @@ def test_from_min_dict(min_profile_data_dict):
     assert profile_data.profile_details.name == "min_profile"
     assert profile_data.crypto_currencies[0].trading_pairs == ['BTC/USDT']
     assert profile_data.crypto_currencies[0].name is None
+    assert profile_data.crypto_currencies[0].enabled is True
+    assert profile_data.crypto_currencies[1].trading_pairs == ['ETH/USDT']
+    assert profile_data.crypto_currencies[1].name is None
+    assert profile_data.crypto_currencies[1].enabled is False
+    assert profile_data.future_exchange_data.default_leverage is None
+    assert profile_data.future_exchange_data.symbol_data == []
     assert profile_data.exchanges == []
     assert profile_data.trader.enabled is True
     assert profile_data.trader_simulator.enabled is False
@@ -236,8 +284,10 @@ def test_from_dict_objects(profile_data_dict):
     })
     # check one element per attribute to be sure it's all parsed
     assert profile_data.profile_details.version == "42.42.1b"
+    assert profile_data.profile_details.nested_strategy_config_id == "123-1221"
     assert profile_data.crypto_currencies[0].trading_pairs == ['BTC/USDT']
     assert profile_data.exchanges[0].exchange_credential_id == "123-plop"
+    assert profile_data.exchanges[0].exchange_account_id == "123-exchange_account_id"
     assert profile_data.trader.enabled is True
     assert profile_data.trader_simulator.enabled is False
     assert profile_data.trader_simulator.starting_portfolio == {'BTC': 10, 'USDT': 1000}
